==> alfresco-repository-23.3.21.2-sources.jar: org/alfresco/service/cmr/activities/ActivityPoster.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.activities;

import org.alfresco.sync.repo.Client;
import org.alfresco.service.cmr.model.FileInfo;
import org.alfresco.service.cmr.repository.NodeRef;

/**
 * A consolidated services for posting file folder activities.
 *
 * @author Gethin James
 */
public interface ActivityPoster
{

    public static final String DOWNLOADED = "org.alfresco.documentlibrary.file-downloaded";
    /**
     * Posts file folder activity.
     * @param activityType required
     * @param path optional
     * @param tenantDomain optional
     * @param siteId required
     * @param parentNodeRef optional
     * @param nodeRef required
     * @param fileName required
     * @param appTool required
     * @param client required
     * @param fileInfo optional
     */
    void postFileFolderActivity(String activityType, String path, String tenantDomain,
                String siteId, NodeRef parentNodeRef, NodeRef nodeRef, String fileName,
                String appTool, Client client, FileInfo fileInfo);

}

==> alfresco-repository-25.3.0.79-sources.jar: org/alfresco/service/cmr/activities/ActivityPoster.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.service.cmr.activities;

import org.alfresco.service.cmr.model.FileInfo;
import org.alfresco.service.cmr.repository.NodeRef;
import org.alfresco.sync.repo.Client;

/**
 * A consolidated services for posting file folder activities.
 *
 * @author Gethin James
 */
public interface ActivityPoster
{

    public static final String DOWNLOADED = "org.alfresco.documentlibrary.file-downloaded";

    /**
     * Posts file folder activity.
     * 
     * @param activityType
     *            required
     * @param path
     *            optional
     * @param tenantDomain
     *            optional
     * @param siteId
     *            required
     * @param parentNodeRef
     *            optional
     * @param nodeRef
     *            required
     * @param fileName
     *            required
     * @param appTool
     *            required
     * @param client
     *            required
     * @param fileInfo
     *            optional
     */
    void postFileFolderActivity(String activityType, String path, String tenantDomain,
            String siteId, NodeRef parentNodeRef, NodeRef nodeRef, String fileName,
            String appTool, Client client, FileInfo fileInfo);

}
